@@ -45,9 +45,10 @@
 #include "google/protobuf/duration.upb.h"
 #include "google/protobuf/struct.upb.h"
 #include "google/protobuf/wrappers.upb.h"
-#include "src/core/lib/config/core_configuration.h"
+#include "src/core/config/core_configuration.h"
 #include "src/core/lib/debug/trace.h"
 #include "src/core/load_balancing/lb_policy_registry.h"
+#include "src/core/util/down_cast.h"
 #include "src/core/util/env.h"
 #include "src/core/util/host_port.h"
 #include "src/core/util/time.h"
@@ -87,7 +88,7 @@ CommonTlsContext UpstreamTlsContextParse(
     const XdsResourceType::DecodeContext& context,
     const XdsExtension& extension, ValidationErrors* errors) {
   const absl::string_view* serialized_upstream_tls_context =
-      absl::get_if<absl::string_view>(&extension.value);
+      std::get_if<absl::string_view>(&extension.value);
   if (serialized_upstream_tls_context == nullptr) {
     errors->AddError("can't decode UpstreamTlsContext");
     return {};
@@ -109,7 +110,7 @@ CommonTlsContext UpstreamTlsContextParse(
     common_tls_context =
         CommonTlsContextParse(context, common_tls_context_proto, errors);
   }
-  if (absl::holds_alternative<absl::monostate>(
+  if (std::holds_alternative<std::monostate>(
           common_tls_context.certificate_validation_context.ca_certs)) {
     errors->AddError("no CA certs configured");
   }
@@ -120,7 +121,7 @@ CommonTlsContext Http11ProxyUpstreamTransportParse(
     const XdsResourceType::DecodeContext& context,
     const XdsExtension& extension, ValidationErrors* errors) {
   const absl::string_view* serialized =
-      absl::get_if<absl::string_view>(&extension.value);
+      std::get_if<absl::string_view>(&extension.value);
   if (serialized == nullptr) {
     errors->AddError("can't decode Http11ProxyUpstreamTransport");
     return {};
@@ -299,7 +300,7 @@ void ParseLbPolicyConfig(const XdsResourceType::DecodeContext& context,
       envoy_config_cluster_v3_Cluster_load_balancing_policy(cluster);
   if (load_balancing_policy != nullptr) {
     const auto& registry =
-        static_cast<const GrpcXdsBootstrap&>(context.client->bootstrap())
+        DownCast<const GrpcXdsBootstrap&>(context.client->bootstrap())
             .lb_policy_registry();
     ValidationErrors::ScopedField field(errors, ".load_balancing_policy");
     const size_t original_error_count = errors->size();
@@ -402,7 +403,7 @@ void ParseUpstreamConfig(
     return;
   }
   absl::string_view* serialized_http_protocol_options =
-      absl::get_if<absl::string_view>(&extension->value);
+      std::get_if<absl::string_view>(&extension->value);
   if (serialized_http_protocol_options == nullptr) {
     errors->AddError("can't decode HttpProtocolOptions");
     return;
@@ -453,24 +454,23 @@ absl::StatusOr<std::shared_ptr<const XdsClusterResource>> CdsResourceParse(
             custom_cluster_type);
     if (typed_config == nullptr) {
       errors.AddError("field not present");
+    } else if (absl::string_view type_url = absl::StripPrefix(
+                   UpbStringToAbsl(google_protobuf_Any_type_url(typed_config)),
+                   "type.googleapis.com/");
+               type_url ==
+               "envoy.extensions.clusters.aggregate.v3.ClusterConfig") {
+      // Retrieve aggregate clusters.
+      ValidationErrors::ScopedField field(
+          &errors,
+          ".value[envoy.extensions.clusters.aggregate.v3.ClusterConfig]");
+      absl::string_view serialized_config =
+          UpbStringToAbsl(google_protobuf_Any_value(typed_config));
+      cds_update->type =
+          AggregateClusterParse(context, serialized_config, &errors);
     } else {
-      absl::string_view type_url = absl::StripPrefix(
-          UpbStringToAbsl(google_protobuf_Any_type_url(typed_config)),
-          "type.googleapis.com/");
-      if (type_url != "envoy.extensions.clusters.aggregate.v3.ClusterConfig") {
-        ValidationErrors::ScopedField field(&errors, ".type_url");
-        errors.AddError(
-            absl::StrCat("unknown cluster_type extension: ", type_url));
-      } else {
-        // Retrieve aggregate clusters.
-        ValidationErrors::ScopedField field(
-            &errors,
-            ".value[envoy.extensions.clusters.aggregate.v3.ClusterConfig]");
-        absl::string_view serialized_config =
-            UpbStringToAbsl(google_protobuf_Any_value(typed_config));
-        cds_update->type =
-            AggregateClusterParse(context, serialized_config, &errors);
-      }
+      ValidationErrors::ScopedField field(&errors, ".type_url");
+      errors.AddError(
+          absl::StrCat("unknown cluster_type extension: ", type_url));
     }
   } else {
     ValidationErrors::ScopedField field(&errors, ".type");
@@ -509,8 +509,9 @@ absl::StatusOr<std::shared_ptr<const XdsClusterResource>> CdsResourceParse(
       ValidationErrors::ScopedField field(&errors, ".lrs_server");
       errors.AddError("ConfigSource is not self");
     }
-    cds_update->lrs_load_reporting_server = std::make_shared<GrpcXdsServer>(
-        static_cast<const GrpcXdsServer&>(context.server));
+    cds_update->lrs_load_reporting_server =
+        std::static_pointer_cast<const GrpcXdsServerTarget>(
+            context.server.target());
   }
   // Record LRS metric propagation.
   auto propagation = MakeRefCounted<BackendMetricPropagation>();
@@ -724,7 +725,7 @@ absl::StatusOr<std::shared_ptr<const XdsClusterResource>> CdsResourceParse(
 
 void MaybeLogCluster(const XdsResourceType::DecodeContext& context,
                      const envoy_config_cluster_v3_Cluster* cluster) {
-  if (GRPC_TRACE_FLAG_ENABLED_OBJ(*context.tracer) && ABSL_VLOG_IS_ON(2)) {
+  if (GRPC_TRACE_FLAG_ENABLED(xds_client) && ABSL_VLOG_IS_ON(2)) {
     const upb_MessageDef* msg_type =
         envoy_config_cluster_v3_Cluster_getmsgdef(context.symtab);
     char buf[10240];
@@ -754,13 +755,13 @@ XdsResourceType::DecodeResult XdsClusterResourceType::Decode(
       UpbStringToStdString(envoy_config_cluster_v3_Cluster_name(resource));
   auto cds_resource = CdsResourceParse(context, resource);
   if (!cds_resource.ok()) {
-    if (GRPC_TRACE_FLAG_ENABLED_OBJ(*context.tracer)) {
+    if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
       LOG(ERROR) << "[xds_client " << context.client << "] invalid Cluster "
                  << *result.name << ": " << cds_resource.status();
     }
     result.resource = cds_resource.status();
   } else {
-    if (GRPC_TRACE_FLAG_ENABLED_OBJ(*context.tracer)) {
+    if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
       LOG(INFO) << "[xds_client " << context.client << "] parsed Cluster "
                 << *result.name << ": " << (*cds_resource)->ToString();
     }
