@@ -14,6 +14,8 @@
 
 #include "test/core/event_engine/test_suite/posix/oracle_event_engine_posix.h"
 
+#include <grpc/event_engine/event_engine.h>
+#include <grpc/support/alloc.h>
 #include <poll.h>
 #include <sys/socket.h>
 #include <unistd.h>
@@ -30,14 +32,10 @@
 #include "absl/strings/str_format.h"
 #include "absl/time/clock.h"
 #include "absl/time/time.h"
-
-#include <grpc/event_engine/event_engine.h>
-#include <grpc/support/alloc.h>
-
 #include "src/core/lib/address_utils/sockaddr_utils.h"
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/strerror.h"
 #include "src/core/lib/iomgr/resolved_address.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/strerror.h"
 
 namespace grpc_event_engine {
 namespace experimental {
