@@ -18,30 +18,21 @@
 
 #include "src/core/lib/iomgr/error.h"
 
+#include <grpc/grpc.h>
+#include <grpc/support/alloc.h>
 #include <string.h>
 
-#include <gmock/gmock.h>
-
 #include "absl/log/log.h"
 #include "absl/strings/str_cat.h"
-
-#include <grpc/grpc.h>
-#include <grpc/support/alloc.h>
-
-#include "src/core/lib/gprpp/crash.h"
-#include "src/core/lib/gprpp/strerror.h"
+#include "gmock/gmock.h"
+#include "src/core/util/crash.h"
+#include "src/core/util/strerror.h"
 #include "test/core/test_util/test_config.h"
 
 TEST(ErrorTest, SetGetInt) {
   grpc_error_handle error = GRPC_ERROR_CREATE("Test");
   EXPECT_NE(error, absl::OkStatus());
   intptr_t i = 0;
-#ifndef NDEBUG
-  // grpc_core::StatusIntProperty::kFileLine is for debug only
-  EXPECT_TRUE(
-      grpc_error_get_int(error, grpc_core::StatusIntProperty::kFileLine, &i));
-  EXPECT_TRUE(i);  // line set will never be 0
-#endif
   EXPECT_TRUE(
       !grpc_error_get_int(error, grpc_core::StatusIntProperty::kStreamId, &i));
   EXPECT_TRUE(!grpc_error_get_int(
@@ -58,22 +49,9 @@ TEST(ErrorTest, SetGetInt) {
 TEST(ErrorTest, SetGetStr) {
   grpc_error_handle error = GRPC_ERROR_CREATE("Test");
 
-  std::string str;
-#ifndef NDEBUG
-  // grpc_core::StatusStrProperty::kFile   is for debug only
-  EXPECT_TRUE(
-      grpc_error_get_str(error, grpc_core::StatusStrProperty::kFile, &str));
-  EXPECT_THAT(str, testing::HasSubstr("error_test.c"));
-  // __FILE__ expands differently on
-  // Windows. All should at least
-  // contain error_test.c
-#endif
-  EXPECT_TRUE(grpc_error_get_str(
-      error, grpc_core::StatusStrProperty::kDescription, &str));
-  EXPECT_EQ(str, "Test");
-
   error = grpc_error_set_str(error, grpc_core::StatusStrProperty::kGrpcMessage,
                              "longer message");
+  std::string str;
   EXPECT_TRUE(grpc_error_get_str(
       error, grpc_core::StatusStrProperty::kGrpcMessage, &str));
   EXPECT_EQ(str, "longer message");
