@@ -26,17 +26,6 @@
 #include <unistd.h>
 #endif
 
-#include <algorithm>
-#include <string>
-#include <vector>
-
-#include "absl/base/attributes.h"
-#include "absl/flags/flag.h"
-#include "absl/flags/parse.h"
-#include "absl/log/check.h"
-#include "absl/log/log.h"
-#include "absl/status/status.h"
-
 #include <grpc/byte_buffer.h>
 #include <grpc/credentials.h>
 #include <grpc/grpc.h>
@@ -47,9 +36,19 @@
 #include <grpc/support/alloc.h>
 #include <grpc/support/time.h>
 
+#include <algorithm>
+#include <string>
+#include <vector>
+
+#include "absl/base/attributes.h"
+#include "absl/flags/flag.h"
+#include "absl/flags/parse.h"
+#include "absl/log/check.h"
+#include "absl/log/log.h"
+#include "absl/status/status.h"
 #include "src/core/ext/transport/chaotic_good/server/chaotic_good_server.h"
 #include "src/core/lib/channel/channel_args.h"
-#include "src/core/lib/gprpp/host_port.h"
+#include "src/core/util/host_port.h"
 #include "src/core/xds/grpc/xds_enabled_server.h"
 #include "test/core/end2end/data/ssl_test_data.h"
 #include "test/core/memory_usage/memstats.h"
@@ -328,7 +327,7 @@ int main(int argc, char** argv) {
                 send_status(&calls[k]);
               }
             }
-            ABSL_FALLTHROUGH_INTENDED;
+            [[fallthrough]];
           // no break here since we want to continue to case
           // FLING_SERVER_SEND_STATUS_SNAPSHOT to destroy the snapshot call
           case FLING_SERVER_SEND_STATUS_SNAPSHOT:
